PAWpySeed: transform_spline Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
transform_spline Struct Reference

`#include <momentum.h>`

## Public Attributes
double * | transform
double ** | spline

## Member Data Documentation

double** transform_spline::spline

double* transform_spline::transform

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/momentum.h